@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="el">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
 <context>
     <name>MainWindow</name>
     <message>
@@ -407,4 +405,4 @@
         <translation>Πρέπει να τρέξετε αυτό το πρόγραμμα με δικαιώματα διαχειριστή.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
