@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nb">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb">
 <context>
     <name>MainWindow</name>
     <message>
@@ -38,7 +36,7 @@
     <message>
         <location filename="../mainwindow.ui" line="531"/>
         <source>Purge residual configurations from removed packages</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjern gjenværende oppsett fra fjernede pakker</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="539"/>
@@ -48,7 +46,7 @@
     <message>
         <location filename="../mainwindow.ui" line="545"/>
         <source>Removal Tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjerningsverktøy</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="583"/>
@@ -284,7 +282,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="493"/>
         <source>Failed to elevate privileges</source>
-        <translation type="unfinished"></translation>
+        <translation>Klarte ikke forhøye privilegier</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="671"/>
@@ -407,4 +405,4 @@
         <translation>Dette programmet må kjøres med administratorrettigheter.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
